==> belenios_1.8+dfsg.orig.tar.xz: belenios-1.8/src/web/web_auth_dummy.ml <==
(**************************************************************************)
(*                                BELENIOS                                *)
(*                                                                        *)
(*  Copyright © 2012-2018 Inria                                           *)
(*                                                                        *)
(*  This program is free software: you can redistribute it and/or modify  *)
(*  it under the terms of the GNU Affero General Public License as        *)
(*  published by the Free Software Foundation, either version 3 of the    *)
(*  License, or (at your option) any later version, with the additional   *)
(*  exemption that compiling, linking, and/or using OpenSSL is allowed.   *)
(*                                                                        *)
(*  This program is distributed in the hope that it will be useful, but   *)
(*  WITHOUT ANY WARRANTY; without even the implied warranty of            *)
(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *)
(*  Affero General Public License for more details.                       *)
(*                                                                        *)
(*  You should have received a copy of the GNU Affero General Public      *)
(*  License along with this program.  If not, see                         *)
(*  <http://www.gnu.org/licenses/>.                                       *)
(**************************************************************************)

open Lwt

let () =
  Eliom_registration.Any.register ~service:Web_services.dummy_post
    (fun () name ->
      Web_auth.run_post_login_handler "dummy"
        (fun _ _ authenticate -> authenticate name)
    )

let () =
  Web_auth.register_pre_login_handler "dummy"
    (fun _ ->
      Web_templates.login_dummy () >>= Eliom_registration.Html.send
    )

==> belenios_1.14+dfsg.orig.tar.xz: belenios-1.14/src/web/web_auth_dummy.ml <==
(**************************************************************************)
(*                                BELENIOS                                *)
(*                                                                        *)
(*  Copyright © 2012-2020 Inria                                           *)
(*                                                                        *)
(*  This program is free software: you can redistribute it and/or modify  *)
(*  it under the terms of the GNU Affero General Public License as        *)
(*  published by the Free Software Foundation, either version 3 of the    *)
(*  License, or (at your option) any later version, with the additional   *)
(*  exemption that compiling, linking, and/or using OpenSSL is allowed.   *)
(*                                                                        *)
(*  This program is distributed in the hope that it will be useful, but   *)
(*  WITHOUT ANY WARRANTY; without even the implied warranty of            *)
(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *)
(*  Affero General Public License for more details.                       *)
(*                                                                        *)
(*  You should have received a copy of the GNU Affero General Public      *)
(*  License along with this program.  If not, see                         *)
(*  <http://www.gnu.org/licenses/>.                                       *)
(**************************************************************************)

open Lwt

let run_post_login_handler =
  Web_auth.register_pre_login_handler ~auth_system:"dummy"
    (fun _ ~state ->
      Pages_common.login_dummy ~state >>= Eliom_registration.Html.send
    )

let () =
  Eliom_registration.Any.register ~service:Web_services.dummy_post
    (fun () (state, name) ->
      run_post_login_handler ~state
        (fun _ _ authenticate -> authenticate name >>= fun x -> return (Ok x))
    )
